@@ -1,34 +1,24 @@
 """
 Underlying methods for different neural network deployments.
 """
-import collections
 import itertools
-import json
+import logging
+import re
 import time
-from pathlib import Path
-from typing import Iterable
+import typing as t
+from pathlib import Path, PosixPath
 from time import perf_counter
 
+import baby.errors
 import h5py
 import numpy as np
-import pandas as pd
-import re
 import requests
-import tensorflow as tf
-from tqdm import tqdm
-
-from agora.abc import ParametersABC, ProcessABC
-import baby.errors
+from agora.abc import ParametersABC
 from baby import modelsets
 from baby.brain import BabyBrain
 from baby.crawler import BabyCrawler
-from requests.exceptions import Timeout, HTTPError
-from requests_toolbelt.multipart.encoder import MultipartEncoder
+from requests.exceptions import HTTPError, Timeout
 
-from agora.io.utils import Cache, accumulate, get_store_path
-
-
-import logging
 
 ################### Dask Methods ################################
 def format_segmentation(segmentation, tp):
@@ -75,7 +65,9 @@ def format_segmentation(segmentation, tp):
 class BabyParameters(ParametersABC):
     def __init__(
         self,
-        model_config,
+        model_config: t.Dict[
+            str, t.Union[str, int, float, bool, t.List[t.Union[int, float]]]
+        ],
         tracker_params,
         clogging_thresh,
         min_bud_tps,
@@ -85,7 +77,7 @@ class BabyParameters(ParametersABC):
         print_info,
         suppress_errors,
         error_dump_dir,
-        tf_version,
+        tf_version: int,
     ):
         self.model_config = model_config
         self.tracker_params = tracker_params
@@ -116,22 +108,39 @@ class BabyParameters(ParametersABC):
             tf_version=2,
         )
 
+    def update_baby_modelset(
+        self, path: t.Union[str, PosixPath, t.Dict[str, str]]
+    ):
+        """
+        Replace default BABY model and flattener with another one from a folder outputted
+        by our standard retraining script.
+        """
+
+        if isinstance(path, dict):
+            weights_flattener = {k: Path(v) for k, v in path.items()}
+        else:
+            weights_dir = Path(path)
+            weights_flattener = {
+                "flattener_file": weights_dir.parent / "flattener.json",
+                "morph_model_file": weights_dir / "weights.h5",
+            }
+
+        self.update("model_config", weights_flattener)
+
 
 class BabyRunner:
     """A BabyRunner object for cell segmentation.
 
     Does segmentation one time point at a time."""
 
-    def __init__(self, tiler, parameters=None, *args, **kwargs):
+    def __init__(self, tiler, parameters=None, **kwargs):
         self.tiler = tiler
         # self.model_config = modelsets()[choose_model_from_params(**kwargs)]
-        self.model_config = modelsets()[
-            (
-                parameters.model_config
-                if parameters is not None
-                else choose_model_from_params(**kwargs)
-            )
-        ]
+        self.model_config = (
+            choose_model_from_params(**kwargs)
+            if parameters is None
+            else parameters.model_config
+        )
         self.brain = BabyBrain(**self.model_config)
         self.crawler = BabyCrawler(self.brain)
         self.bf_channel = self.tiler.get_channel_index("Brightfield")
@@ -179,7 +188,7 @@ class BabyClient:
     max_tries = 50
     sleep_time = 0.1
 
-    def __init__(self, tiler, *args, **kwargs):
+    def __init__(self, tiler):
         self.tiler = tiler
         self._session = None
 
@@ -194,16 +203,16 @@ class BabyClient:
     def get_data(self, tp):
         return self.tiler.get_tp_data(tp, self.bf_channel).swapaxes(1, 3)
 
-    def queue_image(self, img, **kwargs):
-        bit_depth = img.dtype.itemsize * 8  # bit depth =  byte_size * 8
-        data = create_request(img.shape, bit_depth, img, **kwargs)
-        status = requests.post(
-            self.url + f"/segment?sessionid={self.session}",
-            data=data,
-            headers={"Content-Type": data.content_type},
-        )
-        status.raise_for_status()
-        return status
+    # def queue_image(self, img, **kwargs):
+    #     bit_depth = img.dtype.itemsize * 8  # bit depth =  byte_size * 8
+    #     data = create_request(img.shape, bit_depth, img, **kwargs)
+    #     status = requests.post(
+    #         self.url + f"/segment?sessionid={self.session}",
+    #         data=data,
+    #         headers={"Content-Type": data.content_type},
+    #     )
+    #     status.raise_for_status()
+    #     return status
 
     def get_segmentation(self):
         try:
@@ -222,7 +231,7 @@ class BabyClient:
         # Get data
         img = self.get_data(tp)
         # Queue image
-        status = self.queue_image(img, **kwargs)
+        _ = self.queue_image(img, **kwargs)
         # Get segmentation
         for _ in range(self.max_tries):
             try:
@@ -240,7 +249,6 @@ def choose_model_from_params(
     channel="brightfield",
     zoom="60x",
     n_stacks="5z",
-    **kwargs,
 ):
     """
     Define which model to query from the server based on a set of parameters.
@@ -282,4 +290,4 @@ def choose_model_from_params(
             "No model sets found matching {}".format(", ".join(params))
         )
     # Pick the first model
-    return valid_models[0]
+    return modelsets()[valid_models[0]]
